@@ -4,11 +4,7 @@ from integration_testing_environment.integration_testing_environment_ui.editor.i
     content_init
 from integration_testing_environment.integration_testing_environment_ui.editor.menu.build_ite_ui_menu import \
     build_ite_menu
-from integration_testing_environment.integration_testing_environment_ui.editor.redirect_output. \
-    redirect_output_to_tkinter_ui import redirect_output
 from integration_testing_environment.utils.content.content_save import save_content_and_quit
-from integration_testing_environment.utils.manager.redirect_manager.redirect_manager_class import \
-    redirect_manager_instance
 
 
 class ITEUI(EditorMain):
@@ -19,7 +15,6 @@ class ITEUI(EditorMain):
         self.main_window.title("ITE")
         content_init(self)
         build_ite_menu(self)
-        self.program_run_result_textarea.after(10, lambda: redirect_output(self))
 
     def before_close_event(self):
         save_content_and_quit()
@@ -29,7 +24,6 @@ def start_ite(use_theme=None, debug: bool = False, **kwargs):
     ite_ui: ITEUI = ITEUI(use_theme=use_theme, debug=debug, **kwargs)
     if not debug:
         # set use ui is true then we will redirect output to ui
-        redirect_manager_instance.set_ui_setting(ite_ui, True)
         # set some editor setting start main loop
         ite_ui.start_editor()
     return ite_ui
